@@ -1,13 +1,13 @@
 """Low level converters usually used by other functions."""
 import datetime
 import functools
+import importlib
 import re
 import warnings
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Tuple, TypeVar, Union
 
 import numpy as np
-import pkg_resources
 import xarray as xr
 
 try:
@@ -339,19 +339,18 @@ def make_attrs(attrs=None, library=None):
         library_name = library.__name__
         default_attrs["inference_library"] = library_name
         try:
-            version = pkg_resources.get_distribution(library_name).version
+            version = importlib.metadata.version(library_name)
             default_attrs["inference_library_version"] = version
-        except pkg_resources.DistributionNotFound:
+        except importlib.metadata.PackageNotFoundError:
             if hasattr(library, "__version__"):
                 version = library.__version__
                 default_attrs["inference_library_version"] = version
-
     if attrs is not None:
         default_attrs.update(attrs)
     return default_attrs
 
 
-def _extend_xr_method(func, doc="", description="", examples="", see_also=""):
+def _extend_xr_method(func, doc=None, description="", examples="", see_also=""):
     """Make wrapper to extend methods from xr.Dataset to InferenceData Class.
 
     Parameters
@@ -388,13 +387,17 @@ def _extend_xr_method(func, doc="", description="", examples="", see_also=""):
 
     description_default = """{method_name} method is extended from xarray.Dataset methods.
 
-    {description}For more info see :meth:`xarray:xarray.Dataset.{method_name}`
+    {description}
+
+    For more info see :meth:`xarray:xarray.Dataset.{method_name}`.
+    In addition to the arguments available in the original method, the following
+    ones are added by ArviZ to adapt the method to being called on an ``InferenceData`` object.
     """.format(
         description=description, method_name=func.__name__  # pylint: disable=no-member
     )
     params = """
-    Parameters
-    ----------
+    Other Parameters
+    ----------------
     groups: str or list of str, optional
         Groups where the selection is to be applied. Can either be group names
         or metagroup names.
