@@ -669,8 +669,8 @@ def get_draws(fit, variables=None, ignore=None, warmup=False, dtypes=None):
         par_idx = min(
             (dim, i) for i, dim in enumerate(fit.sim["dims_oi"]) if (dim and np.prod(dim) != 0)
         )[1]
-        offset = int(sum(map(np.product, fit.sim["dims_oi"][:par_idx])))
-        par_offset = int(np.product(fit.sim["dims_oi"][par_idx]))
+        offset = int(sum(map(np.prod, fit.sim["dims_oi"][:par_idx])))
+        par_offset = int(np.prod(fit.sim["dims_oi"][par_idx]))
         par_keys = fit.sim["fnames_oi"][offset : offset + par_offset]
         shift = len(par_keys)
         for item in par_keys:
