@@ -25,14 +25,16 @@ def plot_compare(
 ):
     r"""Summary plot for model comparison.
 
-    Models are compared based on their expected log pointwise predictive density (ELPD),
-    the ELPD is estimated either by Pareto smoothed importance sampling leave-one-out
-    cross-validation (LOO) or using the widely applicable information criterion (WAIC).
-    We recommend LOO in line with the work presented by [1]_.
-
+    Models are compared based on their expected log pointwise predictive density (ELPD).
     This plot is in the style of the one used in [2]_. Chapter 6 in the first edition
     or 7 in the second.
 
+    Notes
+    -----
+    The ELPD is estimated either by Pareto smoothed importance sampling leave-one-out
+    cross-validation (LOO) or using the widely applicable information criterion (WAIC).
+    We recommend LOO in line with the work presented by [1]_.
+
     Parameters
     ----------
     comp_df : pandas.DataFrame
@@ -89,6 +91,7 @@ def plot_compare(
     ----------
     .. [1] Vehtari et al. (2016). Practical Bayesian model evaluation using leave-one-out
     cross-validation and WAIC https://arxiv.org/abs/1507.04544
+
     .. [2] McElreath R. (2022). Statistical Rethinking A Bayesian Course with Examples in
     R and Stan, Second edition, CRC Press.
 
