@@ -16,7 +16,7 @@ from ..utils import conditional_jit, conditional_vect, conditional_dask
 from .density_utils import histogram as _histogram
 
 
-__all__ = ["autocorr", "autocov", "ELPDData", "make_ufunc", "wrap_xarray_ufunc"]
+__all__ = ["autocorr", "autocov", "ELPDData", "make_ufunc", "smooth_data", "wrap_xarray_ufunc"]
 
 
 def autocov(ary, axis=-1):
@@ -409,7 +409,7 @@ def not_valid(ary, check_nan=True, check_shape=True, nan_kwargs=None, shape_kwar
     return nan_error | chain_error | draw_error
 
 
-def get_log_likelihood(idata, var_name=None):
+def get_log_likelihood(idata, var_name=None, single_var=True):
     """Retrieve the log likelihood dataarray of a given variable."""
     if (
         not hasattr(idata, "log_likelihood")
@@ -426,9 +426,11 @@ def get_log_likelihood(idata, var_name=None):
     if var_name is None:
         var_names = list(idata.log_likelihood.data_vars)
         if len(var_names) > 1:
-            raise TypeError(
-                f"Found several log likelihood arrays {var_names}, var_name cannot be None"
-            )
+            if single_var:
+                raise TypeError(
+                    f"Found several log likelihood arrays {var_names}, var_name cannot be None"
+                )
+            return idata.log_likelihood[var_names]
         return idata.log_likelihood[var_names[0]]
     else:
         try:
@@ -562,7 +564,25 @@ def _circular_standard_deviation(samples, high=2 * np.pi, low=0, skipna=False, a
 
 
 def smooth_data(obs_vals, pp_vals):
-    """Smooth data, helper function for discrete data in plot_pbv, loo_pit and plot_loo_pit."""
+    """Smooth data using a cubic spline.
+
+    Helper function for discrete data in plot_pbv, loo_pit and plot_loo_pit.
+
+    Parameters
+    ----------
+    obs_vals : (N) array-like
+        Observed data
+    pp_vals : (S, N) array-like
+        Posterior predictive samples. ``N`` is the number of observations,
+        and ``S`` is the number of samples (generally n_chains*n_draws).
+
+    Returns
+    -------
+    obs_vals : (N) ndarray
+        Smoothed observed data
+    pp_vals : (S, N) ndarray
+        Smoothed posterior predictive samples
+    """
     x = np.linspace(0, 1, len(obs_vals))
     csi = CubicSpline(x, obs_vals)
     obs_vals = csi(np.linspace(0.01, 0.99, len(obs_vals)))
@@ -572,3 +592,12 @@ def smooth_data(obs_vals, pp_vals):
     pp_vals = csi(np.linspace(0.01, 0.99, pp_vals.shape[1]))
 
     return obs_vals, pp_vals
+
+
+def get_log_prior(idata, var_names=None):
+    """Retrieve the log prior dataarray of a given variable."""
+    if not hasattr(idata, "log_prior"):
+        raise TypeError("log prior not found in inference data object")
+    if var_names is None:
+        var_names = list(idata.log_prior.data_vars)
+    return idata.log_prior[var_names]
