@@ -432,18 +432,18 @@ def pystan_noncentered_schools(data, draws, chains):
     schools_code = """
         data {
             int<lower=0> J;
-            real y[J];
-            real<lower=0> sigma[J];
+            array[J] real y;
+            array[J] real<lower=0> sigma;
         }
 
         parameters {
             real mu;
             real<lower=0> tau;
-            real eta[J];
+            array[J] real eta;
         }
 
         transformed parameters {
-            real theta[J];
+            array[J] real theta;
             for (j in 1:J)
                 theta[j] = mu + tau * eta[j];
         }
@@ -456,8 +456,8 @@ def pystan_noncentered_schools(data, draws, chains):
         }
 
         generated quantities {
-            vector[J] log_lik;
-            vector[J] y_hat;
+            array[J] real log_lik;
+            array[J] real y_hat;
             for (j in 1:J) {
                 log_lik[j] = normal_lpdf(y[j] | theta[j], sigma[j]);
                 y_hat[j] = normal_rng(theta[j], sigma[j]);
@@ -487,7 +487,7 @@ def pystan_noncentered_schools(data, draws, chains):
 
 
 def bm_schools_model(data, draws, chains):
-    import beanmachine.ppl as bm
+    import beanmachine.ppl as bm  # pylint: disable=import-error
     import torch
     import torch.distributions as dist
 
@@ -552,7 +552,7 @@ def load_cached_models(eight_schools_data, draws, chains, libs=None):
         ("emcee", emcee_schools_model),
         ("pyro", pyro_noncentered_schools),
         ("numpyro", numpyro_schools_model),
-        ("beanmachine", bm_schools_model),
+        # ("beanmachine", bm_schools_model),  # ignore beanmachine until it supports torch>=2
     )
     data_directory = os.path.join(here, "saved_models")
     models = {}
